saneconfig documentation
========================

``saneconfig`` is a dead-simple typed configuration loader for dataclasses.
It merges values from defaults, TOML files, and environment variables.

.. toctree::
   :maxdepth: 2
   :caption: Contents

   usage
   api
